pub fn init<R: Runtime>() -> TauriPlugin<R>Expand description
Initializes the plugin, exposing commands to exit or restart the current process.
pub fn init<R: Runtime>() -> TauriPlugin<R>Initializes the plugin, exposing commands to exit or restart the current process.